Attached - Semantic

## Attached Content

Segment 1
Segment 2
Segment 2
Segment 3

Top

Nested Top

Nested Middle

Nested Bottom

Middle

Top

Middle

Bottom

Bottom

Header | Header | Header
Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Header | Header | Header
Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Segment
Segment

## Header Groups

#### Top Block Header

Segment
Segment

#### Bottom Block Header

#### Top Block Header

Segment

#### Middle Block Header

Segment

#### Bottom Block Header

## Mixed Attached Content

Segment
1
Message

Header | Header | Header
Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Message

Header | Header | Header
Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Header | Header | Header
Cell | Cell | Cell
Cell | Cell | Cell
Cell | Cell | Cell

Segment